@@ -6,8 +6,6 @@
 #include <sys/param.h>
 #include <sys/time.h>
 #include <sys/resource.h>
-/* #include <asm/page.h> */
-/* #include <linux/tasks.h> */
 #include <time.h>
 #include <unistd.h>
 #include <signal.h>
@@ -55,25 +53,6 @@ GtkWidget *summary_cpu;
 GtkWidget *summary_mem;
 GtkWidget *summary_swap = NULL;
 
-static GdkColor bar_cpu_colors [PROC_CPU_SIZE-1] = {
-	{0, 0xffff, 0xffff, 0x4fff},
-	{0, 0xdfff, 0xdfff, 0xdfff},
-	{0, 0xafff, 0xafff, 0xafff},
-	{0, 0, 0, 0},
-};
-
-static GdkColor bar_mem_colors [PROC_MEM_SIZE-1] = {
-	{0, 0xbfff, 0xbfff, 0x4fff},
-	{0, 0xefff, 0xefff, 0x4fff},
-	{0, 0xafff, 0xafff, 0xafff},
-	{0, 0, 0x8fff, 0},
-};
-
-static GdkColor bar_swap_colors [PROC_SWAP_SIZE-1] = {
-	{0, 0xcfff, 0x5fff, 0x5fff},
-	{0, 0, 0x8fff, 0},
-};
-
 static GList *field_list = NULL;
 static GList *geometry_list = NULL;
 static GtkWidget *sort_asc, *sort_dsc;
@@ -126,6 +105,60 @@ static GtkWidget     * renice_msg;
 
 static void procview_cfg_read ();
 
+static gchar *cpu_texts [4] = {
+	N_("User"),  N_("Nice"),   N_("System"),  N_("Idle")
+};
+
+static gchar *mem_texts [4] =  {
+	N_("Other"), N_("Shared"), N_("Buffers"), N_("Free")
+};
+
+static gchar *swap_texts [2] = {
+	N_("Used"),  N_("Free")
+};
+
+static const gchar *cpu_defaults [4] = {
+	"#ffffffff4fff", "#dfffdfffdfff",
+	"#afffafffafff", "#000000000000"
+};
+
+static const gchar *mem_defaults [4] = {
+	"#bfffbfff4fff", "#efffefff4fff",
+	"#afffafffafff", "#00008fff0000"
+};
+
+static const gchar *swap_defaults [2] = {
+	"#cfff5fff5fff", "#00008fff0000"
+};
+
+static void procview_properties_init (GTopPropertiesHook *hook, GtkWidget *win);
+static void procview_properties_update (GTopPropertiesHook *hook);
+static void procview_properties_load (GTopPropertiesHook *hook);
+static void procview_properties_save (GTopPropertiesHook *hook);
+
+static void summary_properties_init (GTopPropertiesHook *hook, GtkWidget *win);
+static void summary_properties_update (GTopPropertiesHook *hook);
+static void summary_properties_load (GTopPropertiesHook *hook);
+static void summary_properties_save (GTopPropertiesHook *hook);
+
+GTopPropertiesHook ProcViewPropertiesHook = {
+	procview_properties_init,
+	NULL,
+	NULL,
+	NULL,
+	NULL,
+	NULL
+};
+
+GTopPropertiesHook SummaryColorsPropertiesHook = {
+	summary_properties_init,
+	NULL,
+	summary_properties_update,
+	summary_properties_load,
+	summary_properties_save,
+	NULL
+};
+
 #define CMP_DINT(NAME) \
 \
 static int cmp_ ## NAME (const ProcProcData **P, const ProcProcData **Q) \
@@ -356,14 +389,19 @@ procview_summary ()
 	hbox = gtk_hbox_new (TRUE, GNOME_PAD_SMALL);
 
 	proc_read_mem (&summary_info);
-	summary_cpu = gnome_proc_bar_new (xpm_cpu, PROC_CPU_SIZE-1, bar_cpu_colors,
-				   procview_cpu);
-	summary_mem = gnome_proc_bar_new (xpm_mem, PROC_MEM_SIZE-2, bar_mem_colors,
-				   procview_mem);
+	summary_cpu = gnome_proc_bar_new
+		(xpm_cpu, PROC_CPU_SIZE-1,
+		 gtop_properties.summary_cpu, procview_cpu);
+
+	summary_mem = gnome_proc_bar_new
+		(xpm_mem, PROC_MEM_SIZE-2,
+		 gtop_properties.summary_mem, procview_mem);
+
 	cfg_has_swap = (summary_info.swap [PROC_SWAP_TOTAL]);
 
-	summary_swap = gnome_proc_bar_new (xpm_swap, PROC_SWAP_SIZE-1, bar_swap_colors,
-					   NULL);
+	summary_swap = gnome_proc_bar_new
+		(xpm_swap, PROC_SWAP_SIZE-1,
+		 gtop_properties.summary_swap, NULL);
 
 	gtk_box_pack_start_defaults (GTK_BOX (hbox), summary_cpu);
 	gtk_box_pack_start_defaults (GTK_BOX (hbox), summary_mem);
@@ -437,12 +475,13 @@ addProcessesView ()
 	gtk_widget_show (clist);
 	gtk_widget_show (handle_box);
 	gtk_widget_show (vbox);
-
+	
 	/* pt = openproc (PROC_FILLUSR); */
 	/* when I don't call meminfo, nice & priority values are malformed */
 	/* don't know why ?!? */
 	/* meminfo (); */
-	/* procview_update (); */
+
+	procview_update ();
 
 	return procview_handler;
 }
@@ -1237,3 +1276,196 @@ procview_update ()
 
 	return TRUE;
 }
+
+static void
+procview_properties_init (GTopPropertiesHook *hook, GtkWidget *win)
+{
+	GtkWidget *vb, *vbox, *frame, *label, *button, *spin, *table;
+	GSList *group;
+	gint i;
+
+	vb    = gtk_vbox_new (FALSE, 0);
+	gtk_container_border_width (GTK_CONTAINER (vb), GNOME_PAD_SMALL);
+	vbox  = gtk_vbox_new (FALSE, 0);
+
+	frame = gtk_frame_new (_("Update times (ms)"));
+	table = gtk_table_new (2, 2, FALSE);
+	gtk_table_set_col_spacings (GTK_TABLE (table), GNOME_PAD_SMALL);
+	gtk_container_border_width (GTK_CONTAINER (table), GNOME_PAD_SMALL);
+
+	label = gtk_label_new (_("Processes list"));
+	gtk_misc_set_alignment (GTK_MISC (label), 1, 0.5);
+	gtk_table_attach_defaults (GTK_TABLE (table), label, 0, 1, 0, 1);
+
+	spin = gtk_spin_button_new (NULL, 1, 0);
+	gtk_table_attach_defaults (GTK_TABLE (table), spin, 1, 2, 0, 1);
+
+	label = gtk_label_new (_("Summary"));
+	gtk_misc_set_alignment (GTK_MISC (label), 1, 0.5);
+	gtk_table_attach_defaults (GTK_TABLE (table), label, 0, 1, 1, 2);
+
+	spin = gtk_spin_button_new (NULL, 1, 0);
+	gtk_table_attach_defaults (GTK_TABLE (table), spin, 1, 2, 1, 2);
+
+	gtk_container_add (GTK_CONTAINER (frame), table);
+	gtk_box_pack_start_defaults (GTK_BOX (vb), frame);
+
+	frame = gtk_frame_new ("");
+	table = gtk_table_new (2, 4, FALSE);
+	gtk_table_set_col_spacings (GTK_TABLE (table), GNOME_PAD << 2);
+
+	label = gtk_check_button_new_with_label (_("Show graphical summary"));
+	gtk_table_attach_defaults (GTK_TABLE (table), label, 0, 2, 0, 1);
+
+	label = gtk_check_button_new_with_label (_("Show cpu usage"));
+	gtk_table_attach_defaults (GTK_TABLE (table), label, 1, 2, 1, 2);
+	label = gtk_check_button_new_with_label (_("Show physical memory usage"));
+	gtk_table_attach_defaults (GTK_TABLE (table), label, 1, 2, 2, 3);
+	label = gtk_check_button_new_with_label (_("Show swap memory usage"));
+	gtk_table_attach_defaults (GTK_TABLE (table), label, 1, 2, 3, 4);
+
+	gtk_container_add (GTK_CONTAINER (frame), table);
+	gtk_box_pack_start_defaults (GTK_BOX (vb), frame);
+
+	frame = gtk_frame_new ("");
+	table = gtk_table_new (2, 3, FALSE);
+	gtk_table_set_col_spacings (GTK_TABLE (table), GNOME_PAD << 2);
+
+	label = gtk_check_button_new_with_label (_("Show text summary"));
+	gtk_table_attach_defaults (GTK_TABLE (table), label, 0, 2, 0, 1);
+
+	label = gtk_check_button_new_with_label (_("Show uptime"));
+	gtk_table_attach_defaults (GTK_TABLE (table), label, 1, 2, 1, 2);
+	label = gtk_check_button_new_with_label (_("Show processes counts"));
+	gtk_table_attach_defaults (GTK_TABLE (table), label, 1, 2, 2, 3);
+
+	gtk_container_add (GTK_CONTAINER (frame), table);
+	gtk_box_pack_start_defaults (GTK_BOX (vb), frame);
+
+	gtk_notebook_append_page
+	  (GTK_NOTEBOOK (GNOME_PROPERTY_BOX (win)->notebook),
+	   vb, gtk_label_new (_("Processes")));
+}
+
+static void
+summary_properties_update (GTopPropertiesHook *hook)
+{
+	gnome_proc_bar_update (GNOME_PROC_BAR (summary_cpu),
+			       gtop_properties.summary_cpu);
+
+	gnome_proc_bar_update (GNOME_PROC_BAR (summary_mem),
+			       gtop_properties.summary_mem);
+
+	gnome_proc_bar_update (GNOME_PROC_BAR (summary_swap),
+			       gtop_properties.summary_swap);
+}
+
+static void
+summary_properties_init (GTopPropertiesHook *hook, GtkWidget *win)
+{
+	GtkWidget *vb, *vbox, *frame, *label, *button, *spin, *table;
+	GSList *group;
+	gint i;
+
+	vb = gtk_vbox_new (FALSE, 0);
+	gtk_container_border_width (GTK_CONTAINER (vb), GNOME_PAD_SMALL);
+	
+	frame = gtk_frame_new (_("Summary CPU"));
+	gtk_container_add (GTK_CONTAINER (frame),
+			   gnome_proc_bar_properties
+			   (4, gtop_temp_properties.summary_cpu, cpu_texts));
+	gtk_box_pack_start (GTK_BOX (vb), frame, FALSE, TRUE, 0);
+
+	frame = gtk_frame_new (_("Summary physical memory"));
+	gtk_container_add (GTK_CONTAINER (frame),
+			   gnome_proc_bar_properties
+			   (4, gtop_temp_properties.summary_mem, mem_texts));
+	gtk_box_pack_start (GTK_BOX (vb), frame, FALSE, TRUE, 0);
+
+	frame = gtk_frame_new (_("Summary swap memory"));
+	gtk_container_add (GTK_CONTAINER (frame),
+			   gnome_proc_bar_properties
+			   (2, gtop_temp_properties.summary_swap, swap_texts));
+	gtk_box_pack_start (GTK_BOX (vb), frame, FALSE, TRUE, 0);
+
+	gtk_notebook_append_page
+	  (GTK_NOTEBOOK (GNOME_PROPERTY_BOX (win)->notebook),
+	   vb, gtk_label_new (_("Summary colors")));
+}
+
+static void
+summary_properties_load (GTopPropertiesHook *hook)
+{
+	char name [BUFSIZ], *tmp;
+	gint i;
+
+	for (i=0; i<4; i++) {
+		GdkColor *color = &(gtop_properties.summary_cpu [i]);
+
+		sprintf (name, "gtop/summary_cpu/color%d=%s", i,
+			 cpu_defaults [i]);
+
+		tmp = gnome_config_get_string (name);
+		gdk_color_parse (tmp, color);
+		g_free (tmp);
+	}
+
+	for (i=0; i<4; i++) {
+		GdkColor *color = &(gtop_properties.summary_mem [i]);
+
+		sprintf (name, "gtop/summary_mem/color%d=%s", i,
+			 mem_defaults [i]);
+
+		tmp = gnome_config_get_string (name);
+		gdk_color_parse (tmp, color);
+		g_free (tmp);
+	}
+
+	for (i=0; i<2; i++) {
+		GdkColor *color = &(gtop_properties.summary_swap [i]);
+
+		sprintf (name, "gtop/summary_swap/color%d=%s", i,
+			 swap_defaults [i]);
+
+		tmp = gnome_config_get_string (name);
+		gdk_color_parse (tmp, color);
+		g_free (tmp);
+	}
+}
+
+static void
+summary_properties_save (GTopPropertiesHook *hook)
+{
+	char name [BUFSIZ], tmp [BUFSIZ];
+	gint i;
+
+	for (i=0; i<4; i++) {
+		GdkColor *color = &(gtop_properties.summary_cpu [i]);
+		
+		sprintf (tmp, "#%04x%04x%04x",
+			 color->red, color->green, color->blue);
+
+		sprintf (name, "gtop/summary_cpu/color%d", i);
+		gnome_config_set_string (name, tmp);
+	}
+
+	for (i=0; i<4; i++) {
+		GdkColor *color = &(gtop_properties.summary_mem [i]);
+
+		sprintf (tmp, "#%04x%04x%04x",
+			 color->red, color->green, color->blue);
+
+		sprintf (name, "gtop/summary_mem/color%d", i);
+		gnome_config_set_string (name, tmp);
+	}
+
+	for (i=0; i<2; i++) {
+		GdkColor *color = &(gtop_properties.summary_swap [i]);
+
+		sprintf (tmp, "#%04x%04x%04x",
+			 color->red, color->green, color->blue);
+
+		sprintf (name, "gtop/summary_swap/color%d", i);
+		gnome_config_set_string (name, tmp);
+	}
+}
